==> nlp_profiler-0.0.1.dev0.tar.gz: nlp_profiler-0.0.1.dev0/nlp_profiler/constants.py <==
DEFAULT_PARALLEL_METHOD = 'default'

SWIFTER_METHOD = 'using_swifter'

GRANULAR_OPTION = 'granular'
HIGH_LEVEL_OPTION = 'high_level'
GRAMMAR_CHECK_OPTION = 'grammar_check'
SPELLING_CHECK_OPTION = 'spelling_check'
PARALLELISATION_METHOD_OPTION = 'parallelisation_method'
NOT_APPLICABLE = "N/A"

NaN = float('nan')

# --- Columns generated
# High-level
## Grammar check
GRAMMAR_CHECK_COL = 'grammar_check'
GRAMMAR_CHECK_SCORE_COL = 'grammar_check_score'

## Spelling check
SPELLING_QUALITY_SCORE_COL = 'spelling_quality_score'
SPELLING_QUALITY_COL = 'spelling_quality'
SPELLING_QUALITY_SUMMARISED_COL = 'spelling_quality_summarised'

## Sentiment analysis
SENTIMENT_POLARITY_SCORE_COL = 'sentiment_polarity_score'
SENTIMENT_POLARITY_COL = 'sentiment_polarity'
SENTIMENT_POLARITY_SUMMARISED_COL = 'sentiment_polarity_summarised'
SENTIMENT_SUBJECTIVITY_SCORE_COL = 'sentiment_subjectivity_score'
SENTIMENT_SUBJECTIVITY_COL = 'sentiment_subjectivity'
SENTIMENT_SUBJECTIVITY_SUMMARISED_COL = 'sentiment_subjectivity_summarised'

# ---
# Granular
DATES_COUNT_COL = 'dates_count'
STOP_WORDS_COUNT_COL = 'stop_words_count'
PUNCTUATIONS_COUNT_COL = 'punctuations_count'
NON_ALPHA_NUMERIC_COUNT_COL = 'non_alpha_numeric_count'
ALPHA_NUMERIC_COUNT_COL = 'alpha_numeric_count'
WHOLE_NUMBERS_COUNT_COL = 'whole_numbers_count'
EMOJI_COUNT_COL = 'emoji_count'
CHARS_EXCL_SPACES_COUNT_COL = 'chars_excl_spaces_count'
DUPLICATES_COUNT_COL = 'duplicates_count'
WORDS_COUNT_COL = 'words_count'
SPACES_COUNT_COL = 'spaces_count'
CHARACTERS_COUNT_COL = 'characters_count'
SENTENCES_COUNT_COL = 'sentences_count'

==> nlp_profiler-0.0.3.tar.gz: nlp_profiler-0.0.3/nlp_profiler/constants.py <==
DEFAULT_PARALLEL_METHOD = 'default'

SWIFTER_METHOD = 'using_swifter'

GRANULAR_OPTION = 'granular'
HIGH_LEVEL_OPTION = 'high_level'
GRAMMAR_CHECK_OPTION = 'grammar_check'
SPELLING_CHECK_OPTION = 'spelling_check'
EASE_OF_READING_CHECK_OPTION = 'ease_of_reading_check'
PARALLELISATION_METHOD_OPTION = 'parallelisation_method'
NOT_APPLICABLE = "N/A"

NaN = float('nan')

# --- Columns generated
# High-level
## Grammar check
GRAMMAR_CHECK_COL = 'grammar_check'
GRAMMAR_CHECK_SCORE_COL = 'grammar_check_score'

## Spelling check
SPELLING_QUALITY_SCORE_COL = 'spelling_quality_score'
SPELLING_QUALITY_COL = 'spelling_quality'
SPELLING_QUALITY_SUMMARISED_COL = 'spelling_quality_summarised'

## Sentiment analysis
SENTIMENT_POLARITY_SCORE_COL = 'sentiment_polarity_score'
SENTIMENT_POLARITY_COL = 'sentiment_polarity'
SENTIMENT_POLARITY_SUMMARISED_COL = 'sentiment_polarity_summarised'
SENTIMENT_SUBJECTIVITY_SCORE_COL = 'sentiment_subjectivity_score'
SENTIMENT_SUBJECTIVITY_COL = 'sentiment_subjectivity'
SENTIMENT_SUBJECTIVITY_SUMMARISED_COL = 'sentiment_subjectivity_summarised'

## Spelling check
EASE_OF_READING_SCORE_COL = 'ease_of_reading_score'
EASE_OF_READING_COL = 'ease_of_reading_quality'
EASE_OF_READING_SUMMARISED_COL = 'ease_of_reading_summarised'

# ---
# Granular
DATES_COUNT_COL = 'dates_count'
STOP_WORDS_COUNT_COL = 'stop_words_count'
PUNCTUATIONS_COUNT_COL = 'punctuations_count'
NON_ALPHA_NUMERIC_COUNT_COL = 'non_alpha_numeric_count'
ALPHA_NUMERIC_COUNT_COL = 'alpha_numeric_count'
WHOLE_NUMBERS_COUNT_COL = 'whole_numbers_count'
EMOJI_COUNT_COL = 'emoji_count'
CHARS_EXCL_SPACES_COUNT_COL = 'chars_excl_spaces_count'
DUPLICATES_COUNT_COL = 'duplicates_count'
COUNT_WORDS_COL = 'count_words'
SPACES_COUNT_COL = 'spaces_count'
CHARACTERS_COUNT_COL = 'characters_count'
SENTENCES_COUNT_COL = 'sentences_count'
NOUN_PHASE_COUNT_COL = 'noun_phase_count'
